bayespy.inference.vmp.nodes.gaussian.WrapToGaussianGammaISO
===========================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. autoclass:: WrapToGaussianGammaISO

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: generated/
   
      ~WrapToGaussianGammaISO.__init__
      ~WrapToGaussianGammaISO.add_plate_axis
      ~WrapToGaussianGammaISO.broadcasting_multiplier
      ~WrapToGaussianGammaISO.delete
      ~WrapToGaussianGammaISO.get_mask
      ~WrapToGaussianGammaISO.get_moments
      ~WrapToGaussianGammaISO.get_shape
      ~WrapToGaussianGammaISO.has_plotter
      ~WrapToGaussianGammaISO.lower_bound_contribution
      ~WrapToGaussianGammaISO.move_plates
      ~WrapToGaussianGammaISO.plot
      ~WrapToGaussianGammaISO.set_plotter
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
      :toctree: generated/
   
      ~WrapToGaussianGammaISO.plates
      ~WrapToGaussianGammaISO.plates_multiplier
   
   